Documentation
¶
Index ¶
- func Clear()
- func GetIntConfig(config map[string]interface{}, key string, defaultValue int) int
- func GetStringConfig(config map[string]interface{}, key, defaultValue string) string
- func GetSupportedTypes() []string
- func IsSupported(generatorType string) bool
- func Register(generatorType string, generator Generator) error
- type Generator
- type Registry
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func GetIntConfig ¶ added in v0.2.0
GetIntConfig exports the helper function for use in media packages
func GetStringConfig ¶ added in v0.2.0
GetStringConfig exports the helper function for use in media packages
func GetSupportedTypes ¶ added in v0.3.0
func GetSupportedTypes() []string
func IsSupported ¶ added in v0.3.0
Types ¶
type Registry ¶ added in v0.3.0
type Registry struct {
// contains filtered or unexported fields
}
func NewRegistry ¶ added in v0.3.0
func NewRegistry() *Registry
Click to show internal directories.
Click to hide internal directories.